%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DEMO for the Energy problem
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This is an interesting application where the value of the coalition is
% not given in tabular form but can be explictly computed 
% Manuele Bicego
% January 2014

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% IMPORTANT
% the characteristic function, which measures the
% value of a set of agents, shoudl be defined
% in a file called "CoalVal.m"
% in this case you can use the file "CoalVal_Energy.m"
% (just rename it as CoalVal.m)
% More info in the README file
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
close all

% parameters for the CoalVal function
params{1} = 70; % pf
params{2} = 80; % pda
params{3} = 1.3; % Kpow

% loading profiles and make them global
clear global profiles
global profiles;
load('SampleEnergyProfiles.mat');

N = size(profiles,1); % number of agents
% define Agents identifiers: just a number between 1 and N (number of
% agents)
A = 1:N;
% define networks: net(i,j) = 1 --> they can stay in the same coalition 
net = ones(N); % all connected

% call CLink (with default method GainLink)
info = CoalitionLinkage(A,net,params);
% call CLink with other options (Single, Complete, Average Link)
infoSL = CoalitionLinkage(A,net,params,'s');
infoCL = CoalitionLinkage(A,net,params,'c');
infoAL = CoalitionLinkage(A,net,params,'a');

% TotalGainValue
fprintf('Total Gain Value\n');
fprintf('Gain Link:     %.3f\n',(info.OptVal - info.SingleCoalVal));
fprintf('Single Link:   %.3f\n',(infoSL.OptVal - infoSL.SingleCoalVal));
fprintf('Complete Link: %.3f\n',(infoCL.OptVal - infoCL.SingleCoalVal));
fprintf('Average Link:  %.3f\n',(infoAL.OptVal - infoAL.SingleCoalVal));

