%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DEMO for the RandCharFun problem
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Problem where the value of the coalition is
% given in tabular form
% Manuele Bicego
% January 2014

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% IMPORTANT
% the characteristic function, which measures the
% value of a set of agents, shoudl be defined
% in a file called "CoalVal.m"
% in this case you can use the file "CoalVal_RCF.m"
% (just rename it as CoalVal.m)
% More info in the README file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


clear all
close all
N = 10; % number of agents
% define Agents identifiers: just a number between 1 and N (number of
% agents)
A = 1:N;
% define networks: net(i,j) = 1 --> they can stay in the same coalition 
net = ones(N); % all connected


clear global St
clear global CF
global St
global CF

for i = 1:N
    % number of all possible subsets of <i> elements from <N> elements
    nsubsets(i) = nchoosek(N,i);
    % all possible subsets of length <i>
    St{i} = combntns(1:N,i);
    % Corresponding Characteristic Function
    CF{i} = normrnd(i,sqrt(i),[nsubsets(i),1]);
end
params = 0;
% no parameters



% call CLink (with default method GainLink)
info = CoalitionLinkage(A,net,params);
% call CLink with other options (Single, Complete, Average Link)
infoSL = CoalitionLinkage(A,net,params,'s');
infoCL = CoalitionLinkage(A,net,params,'c');
infoAL = CoalitionLinkage(A,net,params,'a');

% TotalGainValue
fprintf('Total Gain Value\n');
fprintf('Gain Link:     %.3f\n',(info.OptVal - info.SingleCoalVal));
fprintf('Single Link:   %.3f\n',(infoSL.OptVal - infoSL.SingleCoalVal));
fprintf('Complete Link: %.3f\n',(infoCL.OptVal - infoCL.SingleCoalVal));
fprintf('Average Link:  %.3f\n',(infoAL.OptVal - infoAL.SingleCoalVal));

